@@ -64,11 +64,16 @@
 #include <errno.h>
 #ifndef HAVE_DIR
 #include <dirent.h>
+#include <limits.h> /* for _POSIX_PATH_MAX */
+#include <stdlib.h> /* for `qsort'. */
 #else
 #include <sys/dir.h>
-#define dirent direct
+#define dirent direct 
+#include <limits.h> /* for _POSIX_PATH_MAX */
+#include <stdlib.h> /* for `qsort'. */
 #endif
 #include <stdio.h>
+#include <pwd.h>
 
 extern char *getenv();
 
@@ -79,7 +84,9 @@ extern char *actual_path;
 
 #define Offset(field) XtOffsetOf(FileNominatorRec, fileNominator.field)
 
+#ifdef ACTION_PROBLEM
 static int first_in = 1; 
+#endif
 
 static XtResource resources[] = {
     {XtNselectCallback, XtCCallback, XtRCallback, sizeof(XtCallbackList),
@@ -110,6 +117,9 @@ static XtResource resources[] = {
 #define BellLevel(w) (((FileNominatorWidget) w)->fileNominator.bell_level)
 
 
+
+static struct passwd *my_passwd;
+
 static char pathTranslations[] =
     "<BtnDown>:reset() MakeMenu() XawPositionSimpleMenu(menu) MenuPopup(menu)";
 
@@ -473,12 +483,16 @@ Initialize(req, new, args, num_args)
 #endif    
     XtOverrideTranslations(Child(fnw,path_widget),
 			   XtParseTranslationTable(pathTranslations));
+#ifdef ACTION_PROBLEM
+if (first_in == 1){ 
+#endif
     XtAppAddActions(XtWidgetToApplicationContext(new),
 		    pathActions, XtNumber(pathActions));
-if (first_in == 1){ 
     XawSimpleMenuAddGlobalActions(XtWidgetToApplicationContext(new));
+#ifdef ACTION_PROBLEM
     first_in = 0;  
     }  
+#endif
 
 #ifdef GERMAN
     Child(fnw,cancel_widget)
@@ -680,7 +694,7 @@ Nominate(w, event, params, num_params)
      Cardinal *num_params;
 {
     FileNominatorWidget fnw;
-    char *nomination, *home, selection[MAXPATHLEN], *newPath, *r;
+    char *nomination, *home, *name_ende, selection[MAXPATHLEN], *newPath, *r;
     struct stat fstats;
     int status, len;
 
@@ -702,11 +716,30 @@ Nominate(w, event, params, num_params)
     {
 	strcpy(selection, nomination);
     }
-    else if (*nomination == '~' && (home = getenv("HOME")))
+    else if (*nomination == '~' && *(nomination+1) == '\0' &&
+	    (home = getenv("HOME")))
     {
 	strcpy(selection, home);
 	strcat(selection, &nomination[1]);
     }
+    else if (*nomination == '~')
+    {   name_ende  = strchr(nomination, '/');
+	if (name_ende != NULL){
+	   *name_ende = '\0';
+	   name_ende++;
+        }
+	my_passwd = getpwnam (&nomination[1]);
+	if (my_passwd!=NULL){
+	   strcpy(selection, my_passwd->pw_dir);
+	   if (name_ende != NULL){
+              strcat(selection, "/");
+	      strcat(selection, name_ende);
+	      }
+           }
+        else if (home = getenv("HOME"))
+	   strcpy(selection, home);
+         
+    }
     else
     {
 	if (strlen(CurrentDir(fnw)) > 1)
@@ -771,20 +804,64 @@ Nominate(w, event, params, num_params)
     }
 }
 
+#ifndef HAVE_DIR
+/* Comparison function for dirent*, used by `qsort'. */
+static int
+direntpcmp( i, j)
+struct dirent **i, **j;
+{
+    return (strcmp ((*i)->d_name, (*j)->d_name ));
+}
+#endif
+
 static void
 FillWindow(fnw)
-     Widget fnw;
+    Widget fnw;
 {
     XFontStruct *font;
     Dimension height, internalHeight, rowSpacing;
     int num, newNum, idx;
-    struct dirent **namelist;
+    struct dirent  **namelist;
+ #ifndef HAVE_DIR
+    DIR *dirp;
+    struct dirent *direntp;
+    int direntp_size;
+ #else
     extern int alphasort();
+ #endif 
     char buf[MAXPATHLEN], *bp;
     String name;
     struct stat fstats;
-    
+    unsigned int namlen;
+ #ifdef HAVE_DIR
     num = scandir(CurrentDir(fnw), &namelist, (int(*)())0, alphasort);
+ #else
+    /* Read the directory `CurrentDir(fnw)'
+       and set the `dirent's in `namelist'. */
+       dirp = opendir( CurrentDir(fnw) );
+       direntp_size = sizeof(struct dirent)+ _POSIX_PATH_MAX;
+       direntp = (struct dirent *)XtMalloc( direntp_size );
+       /* Read the directory a first time, to get              */
+       /* the number `num' of entries and to allocate namedir. */
+       num = 0;
+       while ( (direntp = readdir(dirp)) != NULL ) num++;
+       namelist = (struct dirent **)XtMalloc( (num+1)*sizeof(struct dirent *));
+       num = 0;
+       rewinddir( dirp );
+       while ( TRUE ) {
+	 if ( (direntp = readdir(dirp)) == NULL ) break;
+	 namelist[num] = (struct dirent *) XtMalloc(direntp_size);
+	 bcopy(direntp, namelist[num], direntp_size);
+	 num++;
+	 direntp = (struct dirent *)XtMalloc( direntp_size );
+       }
+       XtFree( (char *)direntp );
+       (void)closedir( dirp );
+
+    /* Sort the directory entries in `namelist'. */
+       qsort( namelist, num, sizeof(struct dirent*), direntpcmp );
+ #endif 
+    
     if (num <= 0)
     {
 	return;
