@@ -119,15 +119,16 @@ String fieldNames[MAX_FIELDS] = {
    "crossref",
    "key",
    "author",
+   "editor",
    "title",
    "booktitle",
    "institution",
    "journal",
    "organization",
    "chapter",
+   "pages",
    "year",
    "month",
-   "editor",
    "publisher",
    "address",
    "school",
@@ -135,7 +136,6 @@ String fieldNames[MAX_FIELDS] = {
    "howpublished",
    "volume",
    "number",
-   "pages",
    "series",
    "type",
    "note",
@@ -202,6 +202,8 @@ XtResource resources[] = {
 	Offset(displayErrWin), XtRString, (XtPointer)"True" },
    { "focus", "Focus", XtRBoolean, sizeof(Boolean),
 	Offset(focus), XtRString, (XtPointer)"True" },
+   { "orig", "Orig", XtRBoolean, sizeof(Boolean),
+	Offset(orig), XtRString, (XtPointer)"False" },
    { "bibfile", "Bibfile", XtRString, sizeof(String),
 	Offset(bibfile), XtRString, (XtPointer)NULL },
    { "rcfile", "Rcfile", XtRString, sizeof(String),
@@ -210,6 +212,10 @@ XtResource resources[] = {
 	Offset(bibdir), XtRString, (XtPointer)NULL },
    { "focusColor", "FocusColor", XtRPixel, sizeof(Pixel),
 	Offset(focusColor), XtRString, XtDefaultBackground },
+   { "reqColor", "ReqColor", XtRPixel, sizeof(Pixel),
+	Offset(reqColor), XtRString, XtDefaultBackground },
+   { "authedColor", "AuthedColor", XtRPixel, sizeof(Pixel),
+	Offset(authedColor), XtRString, XtDefaultBackground },
 };
 #undef Offset
 
@@ -232,6 +238,8 @@ static XrmOptionDescRec optionDesc[] = {
    { "+displayErrWin","*displayErrWin",  XrmoptionNoArg, (XtPointer)"off" },
    { "-focus",        "*focus",      XrmoptionNoArg, (XtPointer)"on" },
    { "+focus",        "*focus",      XrmoptionNoArg, (XtPointer)"off" },
+   { "-orig",        "*orig",      XrmoptionNoArg, (XtPointer)"on" },
+   { "+orig",        "*orig",      XrmoptionNoArg, (XtPointer)"off" },
    { "-rcfile",      "*rcfile",      XrmoptionSepArg, (XtPointer)NULL },
    { "-bibdir",      "*bibdir",      XrmoptionSepArg, (XtPointer)NULL },
    { "-file",        "*bibfile",     XrmoptionSepArg, (XtPointer)NULL } 
@@ -387,6 +395,7 @@ static char *help[] = {
  "   -reqFields    none            Disallow empty required fields\n",
  "   -ignoreCase   none            Ignore case in search\n",
  "   -focus        none            Use <tab> and <esc> key in card window\n",
+ "   -orig         none            Edit fields in original style\n",
  "   +quiet        none            Turn on/off beep on error\n",
  "   +iconsOnDesk  none            Don't keep icons on bibview desktop\n",
  "   +makeBackup   none            Don't save files to backup on save\n",
@@ -394,6 +403,7 @@ static char *help[] = {
  "   +reqFields    none            Allow empty required fields\n",
  "   +ignoreCase   none            Use case in search\n",
  "   +focus        none            Use mouse in card window\n",
+ "   +orig         none            Edit fields in bibview style\n",
  "   -file         BibTeX File     Load BibTeX-File on startup\n",
  "   -rcfile       bibview rcFile  Use specific configuration file\n",
  "   -help         none            Show this list\n",
@@ -439,6 +449,7 @@ processCommandlineOptions (void)
    optionsStatus[OPT_PRINT_AS_BIB]    = options.printAsBib;
    optionsStatus[OPT_DISPLAY_ERRWIN]  = options.displayErrWin;
    optionsStatus[OPT_FOCUS]           = options.focus;
+   optionsStatus[OPT_ORIG]            = options.orig;
 }
 
 
@@ -567,6 +578,7 @@ int i, j;
    requiredfields[book][nyear] = '1';
 
    standardfields[book][nvolume] = '1';
+   standardfields[book][nnumber] = '1';
    standardfields[book][nseries] = '1';
    standardfields[book][naddress] = '1';
    standardfields[book][nedition] = '1';
@@ -574,6 +586,7 @@ int i, j;
 /* booklet */
    standardfields[booklet][ntitle] =
    requiredfields[booklet][ntitle] = '1';
+
    standardfields[booklet][nauthor] = '1';
    standardfields[booklet][nhowpublished] = '1';
    standardfields[booklet][naddress] = '1';
@@ -588,6 +601,9 @@ int i, j;
    requiredfields[conference][nyear] = '1';
 
    standardfields[conference][neditor] = '1';
+   standardfields[conference][nseries] = '1';
+   standardfields[conference][nvolume] = '1';
+   standardfields[conference][nnumber] = '1';
    standardfields[conference][npages] = '1';
    standardfields[conference][norganization] = '1';
    standardfields[conference][npublisher] = '1';
@@ -609,8 +625,10 @@ int i, j;
    requiredfields[inbook][nyear] = '1';
 
    standardfields[inbook][nvolume] = '1';
+   standardfields[inbook][nnumber] = '1';
    standardfields[inbook][nseries] = '1';
    standardfields[inbook][naddress] = '1';
+   standardfields[inbook][ntype] = '1';
    standardfields[inbook][nedition] = '1';
 
 /* incollection */
@@ -625,6 +643,11 @@ int i, j;
    requiredfields[incollection][nyear] = '1';
 
    standardfields[incollection][neditor] = '1';
+   standardfields[incollection][nedition] = '1';
+   standardfields[incollection][nvolume] = '1';
+   standardfields[incollection][nnumber] = '1';
+   standardfields[incollection][nseries] = '1';
+   standardfields[incollection][ntype] = '1';
    standardfields[incollection][nchapter] = '1';
    standardfields[incollection][npages] = '1';
    standardfields[incollection][naddress] = '1';
@@ -639,11 +662,15 @@ int i, j;
    requiredfields[inproceedings][nyear] = '1';
 
    standardfields[inproceedings][neditor] = '1';
+   standardfields[inproceedings][nseries] = '1';
+   standardfields[inproceedings][nvolume] = '1';
+   standardfields[inproceedings][nnumber] = '1';
    standardfields[inproceedings][npages] = '1';
    standardfields[inproceedings][norganization] = '1';
    standardfields[inproceedings][npublisher] = '1';
    standardfields[inproceedings][naddress] = '1';
 
+
 /* manual */
    standardfields[manual][ntitle] =
    requiredfields[manual][ntitle] = '1';
@@ -663,6 +690,7 @@ int i, j;
    requiredfields[mastersthesis][nyear] = '1';
 
    standardfields[mastersthesis][naddress] = '1';
+   standardfields[mastersthesis][ntype] = '1';
 
 /* misc */
    standardfields[misc][nauthor] = '1';
@@ -679,6 +707,7 @@ int i, j;
    requiredfields[phdthesis][nyear] = '1';
 
    standardfields[phdthesis][naddress] = '1';
+   standardfields[phdthesis][ntype] = '1';
       
 /* proceedings */
    standardfields[proceedings][ntitle] =
@@ -686,6 +715,9 @@ int i, j;
    requiredfields[proceedings][nyear] = '1';
 
    standardfields[proceedings][neditor] = '1';
+   standardfields[proceedings][nvolume] = '1';
+   standardfields[proceedings][nnumber] = '1';
+   standardfields[proceedings][nseries] = '1';
    standardfields[proceedings][npublisher] = '1';
    standardfields[proceedings][norganization] = '1';
    standardfields[proceedings][naddress] = '1';
