@@ -28,7 +28,7 @@
 #define PROGNAME	   "bibView"
 #define DEFAULT_RCFILE     ".bibviewrc"
 #define MAX_BIBTEX_TYPES   30   
-#define MAX_FIELDS         50   
+#define MAX_FIELDS         80   
 #define MAX_ICONNAMELEN	   25
 #define MAX_FILEPATHLEN    1024
 #define MAX_FILENAMELEN    256
@@ -73,6 +73,9 @@ typedef int Errcode;  /* return type for error codes */
 #define ERR_COLL_SAME_BIB       -15
 #define ERR_COPY_SAME_BIB       -16
 #define ERR_COPY_SAME_LIST      -17
+#define ERR_CROSSEMPTY      	-18
+#define ERR_CROSSNOTFOUND      	-19
+
 
 /* gui errors */
 #define ERR_NOCASCADE		-30
@@ -163,15 +166,16 @@ typedef enum {
             ncrossref,
             nkey,
             nauthor,
+            neditor,
             ntitle,
             nbooktitle,
             ninstitution,
             njournal,
             norganization,
             nchapter,
+            npages,
             nyear,
             nmonth,
-            neditor,
             npublisher,
    	    naddress,
             nschool,
@@ -179,10 +183,8 @@ typedef enum {
             nhowpublished,
             nvolume,
             nnumber,
-            npages,
             nseries,
             ntype,
-            ncategory,
             nnote,
             nannote,
 	    nillegal
@@ -259,6 +261,8 @@ typedef struct {
 	  change,	/* change command button */
 	  duplicate,	/* duplicate command button */
 	  copy,		/* copy command button */
+	  crossref,	/* copy command button */
+	  next,  	/* next command button */
 	  close,	/* close command button */
 	  cardDesk,	/* desktop for general attribs for all cards */
 	  cardFlds,	/* desktop on which to place display widgets */
@@ -282,6 +286,7 @@ typedef struct {
    AnnoteWinPtr aw;	/* ptr to annote window data */
    Boolean extended;    /* user fields displayed (T/F) */
    Boolean changed;	/* card changed flag */
+   Boolean new;  	/* card is new flag */
    void  *bp;		/* ptr to bib card belongs to */
 } Card, *CardPtr;
 
@@ -375,12 +380,32 @@ typedef struct {
    int nextCardPos;			/* pos of next opened card */
 } Bib, *BibPtr;
 
+typedef struct {
+   Boolean quiet;
+   Boolean iconsOnDesk;
+   Boolean makeBackup;
+   Boolean autoCheck;
+   Boolean reqFields;
+   Boolean ignoreCase;
+   Boolean printAsBib;
+   Boolean displayErrWin;
+   Boolean focus;
+   Boolean orig;
+   String  bibfile;
+   String  rcfile;
+   String  bibdir;
+   Pixel   focusColor; 
+   Pixel   reqColor; 
+   Pixel   authedColor; 
+} OptionsRec;
+
+
 #define	SORT_MAINKEY		-1
 #define	SORT_UNSRT		-2
 #define	SORT_TYPE		-3
 
 /* codes and macros for options functions */
-#define OPT_MAX_OPTION		8+1 /* plus line in menu */
+#define OPT_MAX_OPTION		10+1 /* plus line in menu */
 #define OPT_BEEP_ON_ERROR       1
 #define OPT_BACKUP_ON_SAVE      2
 #define OPT_ICON_ON_DESKTOP     3
@@ -389,6 +414,8 @@ typedef struct {
 #define OPT_IGNORE_CASE         6
 #define OPT_PRINT_AS_BIB	7
 #define OPT_DISPLAY_ERRWIN	8
+#define OPT_FOCUS	        9
+#define OPT_ORIG	        10
 
 #if !defined(COT_OPT)
 extern Boolean optionsStatus[];
@@ -401,6 +428,8 @@ extern Boolean optionsStatus[];
 #define cotIgnoreCase()	        (optionsStatus[OPT_IGNORE_CASE])
 #define cotPrintAsBib()	        (optionsStatus[OPT_PRINT_AS_BIB])
 #define cotDisplayErrWin()	(optionsStatus[OPT_DISPLAY_ERRWIN])
+#define cotFocus()	        (optionsStatus[OPT_FOCUS])
+#define cotOrig()	        (optionsStatus[OPT_ORIG])
 
 
 /* Prototypes */
@@ -487,6 +516,9 @@ void ccdDeleteCardCmd (Widget w, XtPointer clientData, XtPointer callData);
 void ccdAnnoteCardCmd (Widget w, XtPointer clientData, XtPointer callData);
 void ccdChangeCardCmd (Widget w, XtPointer clientData, XtPointer callData);
 void ccdCopyCardCmd (Widget w, XtPointer clientData, XtPointer callData);
+void ccdOpenCrossrefCmd (Widget w, XtPointer clientData, XtPointer callData);
+void ccdNextCardCmd (Widget w, XtPointer clientData, XtPointer callData);
+void ccdNextChangeCmd (Widget w, XtPointer clientData, XtPointer callData);
 void ccdDuplicateCardCmd (Widget w, XtPointer clientData, XtPointer callData);
 Errcode ccdCopyCard1 (BibPtr bp);
 Errcode ccdCopyCard (BibPtr bp, CardPtr cp);
@@ -599,7 +631,7 @@ Errcode glbMakeBackup(String path);
 /* db_tree.c */
 Errcode dbtInsert (BibPtr bp, CardData *card);
 Errcode dbtDelete (int treeIdx, CardData *card, int *deleted);
-Errcode dbtSearch (int treeIdx, CardData **card);
+Errcode dbtSearch (int treeIdx, CardData **card, CardListNode **list);
 Errcode dbtMakeCard (CardData **card);
 Errcode dbtDeleteCard (CardData **card);
 Errcode dbtMakeTreeList (int treeIdx, int listIdx);
