@@ -42,11 +42,17 @@
 /* ------------------------- */
 extern Widget topLevel, mainMenu, desktop;
 extern Pixmap questPixmap, annoteIconPixmap;
+extern Pixel back, fore, focus;
+extern int max_fields;
 
 
 /* macros and definitions */
 /* ---------------------- */
 
+/* external functions */
+extern void string_event();
+extern CardPtr getCardPtr();
+
 
 /* local function prototypes */
 /* ------------------------- */
@@ -63,6 +69,20 @@ static Errcode annoteClose (CardPtr cp);
 static void annoteSaveCmd (Widget w, XtPointer clientData, XtPointer callData);
 static void annoteCloseCmd (Widget w, XtPointer clientData, XtPointer callData);
 static void DeleteOkCmd (Widget w, XtPointer clientData, XtPointer callData);
+static void close_annote ();
+static void save_annote ();
+static void save_close_annote ();
+
+static XtActionsRec annote_actions[] = {
+   "string", string_event, 
+   "close", close_annote,
+   "save", save_annote,
+   "saveclose", save_close_annote
+};
+
+#ifdef ACTION_PROBLEM
+static int first_in = 1;
+#endif
 
 
 /* exported variables */
@@ -74,6 +94,45 @@ static void DeleteOkCmd (Widget w, XtPointer clientData, XtPointer callData);
 CardPtr gcp;
 
 
+/*********************************************************************/
+/* close_annote:                                                     */
+/*    Action for "close" in annoteWindow                             */
+/*********************************************************************/
+void 
+close_annote (Widget w)
+{
+ CardPtr cp;
+ cp = getCardPtr(w);
+ annoteCloseCmd (w, (XtPointer)cp, NULL);    
+}
+
+
+/*********************************************************************/
+/* save_annote:                                                      */
+/*    Action for "save" in annoteWindow                              */
+/*********************************************************************/
+void 
+save_annote (Widget w)
+{
+ CardPtr cp;
+ cp = getCardPtr(w);
+ annoteSaveCmd (w, (XtPointer)cp, NULL);    
+}
+
+
+/*********************************************************************/
+/* save_close_annote:                                                */
+/*    Action for "save" in annoteWindow                              */
+/*********************************************************************/
+void 
+save_close_annote (Widget w)
+{
+ CardPtr cp;
+ cp = getCardPtr(w);
+ annoteSaveCmd (w, (XtPointer)cp, NULL);    
+ annoteCloseCmd (w, (XtPointer)cp, NULL);    
+}
+
 /*********************************************************************/
 /* ccdNewCardCmd:                                                    */
 /*    Callback function for command "New" in bib window              */
@@ -113,6 +172,293 @@ CardPtr cp;
 }
 
 
+
+/*********************************************************************/
+/* ccdNextCardCmd:                                                   */
+/*    Callback function for command "Next" in card window            */
+/*********************************************************************/
+void 
+ccdNextCardCmd (Widget w, XtPointer clientData, XtPointer callData)
+{
+CardPtr cp = (CardPtr)clientData;
+BibPtr bp = (BibPtr)cp->bp;
+CardWidgetsPtr cwp = &cp->cw->ct.cw;
+CardDataList cl;
+Errcode status;
+XawTextBlock textblock;
+XawTextBlock tbl[MAX_FIELDS];
+CardData *hcard = NULL;
+String str;
+int  i;
+CardType type;
+
+   if (cp->aw != NULL)
+      annoteClose(cp);
+   /* save data from text widgets to card */
+   if ((status = gucSaveCardData(cp)) != OK) {
+      guwError(status);
+      gulCloseListWin(bp);
+      return;
+   }
+
+   /* Check if data in card is OK */
+   if (cotRequiredFields()) {
+      if ((status = dbtTestCard(cp->cd)) != DBT_OK) {
+         guwWarning(status);
+	 }
+   }
+
+   /* insert new card in data tree, possibly new mainkey */
+   CopyCard(&hcard, cp->cd);
+   if ((status = dbtInsert(bp, hcard)) != DBT_OK) { 
+      guwError(status);
+      gulCloseListWin(bp);
+      return;
+   }
+   
+   bp->changed = TRUE;
+   cp->changed = FALSE;
+   cp->new = TRUE;
+
+   /* insert card in list of cards for list window */
+   if (gulListWinExists(bp)) {
+      cl = bp->lw->cardLst;
+      if ((status = dbtCardListInsert(&cl,hcard,bp->sortedby)) != DBT_OK) { 
+         guwError(status);
+         return;
+         }
+      bp->lw->cardLst = NULL;
+      if ((status = gulReplaceListData(bp, cl)) != OK) {
+         guwError(status);
+         gulCloseListWin(bp);
+         }
+   }
+   
+   textblock.firstPos = 0;
+   textblock.length = 0;
+   textblock.ptr = NULL;
+   textblock.format = FMT8BIT;
+
+   XawTextReplace(cwp->mainkey, (XawTextPosition) 0, 
+          (XawTextPosition) strlen(cp->cd->mainkey),
+          (XawTextBlock *) &textblock);
+   XawTextSetInsertionPoint(cwp->mainkey, (XawTextPosition) 0);
+   XtVaGetValues(cwp->mainkey, XtNstring, &str, NULL);
+   for (i=0;i<max_fields;i++){
+      if (cwp->wfield[2*i+1]){
+         tbl[i].firstPos = 0;
+         tbl[i].length = 0;
+         tbl[i].ptr = NULL;
+         tbl[i].format = FMT8BIT;
+
+         XawTextReplace(cwp->wfield[2*i+1], (XawTextPosition) 0, 
+             (XawTextPosition) strlen(cp->cd->field[i]),
+             (XawTextBlock *) &(tbl[i]));
+         XawTextSetInsertionPoint(cwp->wfield[2*i+1], (XawTextPosition) 0);
+         XtVaGetValues(cwp->wfield[2*i+1], XtNstring, &str, NULL);
+	 }
+      }
+
+   dbtDeleteCard(&hcard);
+
+   if (cp->aw != NULL)
+      annoteClose(cp);
+   /* create new internal data for a card window */
+   type=cp->cd->cardtype;
+   dbtDeleteCard(&(cp->cd));
+   if ((status = dbtMakeCard(&(cp->cd))) != DBT_OK) {
+      guwError(status);
+      return;
+   }
+   cp->aw=NULL;
+   if (cp->extended){
+      XtDestroyWidget(cp->cw->usrFldVport);
+      XtResizeWidget(cp->cw->cardShell, cp->cw->width, cp->cw->height,
+	 cp->cw->borderWidth);
+      }
+   cp->extended=FALSE;
+      
+   cp->cd->cardtype = type;
+   if ((cp->cd->cardtypestr = glbNewString(glbTypeToName(type))) == NULL) {
+      guwError(ERR_NOMALLOC);
+      dbtDeleteCard(&cp->cd);
+      return;
+      }
+   
+   if (cotFocus()){
+      for (i=0;i<max_fields;i++){
+         if (cwp->wfield[2*i+1]){
+           XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, fore, NULL);
+         }
+      } 
+      XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
+      XtSetKeyboardFocus(cp->cw->cardFlds, cwp->mainkey);
+   }
+   XtRemoveAllCallbacks(cp->cw->change, XtNcallback);
+   XtRemoveAllCallbacks(cp->cw->next, XtNcallback);
+   XtAddCallback(cp->cw->change, XtNcallback, ccdSaveCardCmd, (XtPointer)cp);
+   XtAddCallback(cp->cw->next, XtNcallback, ccdNextCardCmd, (XtPointer)cp);
+
+}
+
+/*********************************************************************/
+/* ccdNextChangeCmd:                                                 */
+/*    Callback function for command "Next" in card window            */
+/*********************************************************************/
+void 
+ccdNextChangeCmd (Widget w, XtPointer clientData, XtPointer callData)
+{
+CardPtr cp = (CardPtr)clientData;
+BibPtr bp = (BibPtr)cp->bp;
+CardWidgetsPtr cwp = &cp->cw->ct.cw;
+CardDataList cl, clp;
+Errcode status;
+XawTextBlock textblock;
+XawTextBlock tbl[MAX_FIELDS];
+CardData *hcard = NULL;
+String str;
+int  i, del_erg;
+CardType type;
+
+   /* delete old card from data tree */
+   if ((status = dbtDelete(bp->treeIdx, cp->cd, &del_erg)) != DBT_OK) {
+      guwError(status);
+      return;
+   }
+
+   if (cp->aw != NULL)
+      annoteClose(cp);
+
+   /* remove old card from list of cards for list window, keep node */
+   if (gulListWinExists(bp)) {
+      cl = clp = bp->lw->cardLst;
+      if (strcmp(cp->cd->mainkey, clp->data->mainkey) == 0) {
+	 dbtDeleteCard(&clp->data);
+         cl = cl->next;
+      }
+      else {
+	 while (clp->next != NULL) {
+	    if (strcmp(cp->cd->mainkey, clp->next->data->mainkey) == 0) {
+               dbtDeleteCard(&clp->next->data);
+	   /*    clp = clp->next; */
+	       clp->next = clp->next->next;
+	       break;
+	    }
+	    clp = clp->next;
+	 } /* endwhile */
+      } /* endelse */
+   } /* endif */
+
+   /* save data from text widgets to card */
+   if ((status = gucSaveCardData(cp)) != OK) {
+      guwError(status);
+      gulCloseListWin(bp);
+      return;
+   }
+
+   /* Check if data in card is OK */
+   if (cotRequiredFields()) {
+      if ((status = dbtTestCard(cp->cd)) != DBT_OK) {
+         guwWarning(status);
+	 }
+   }
+
+   /* insert new card in data tree, possibly new mainkey */
+   CopyCard(&hcard, cp->cd);
+   if ((status = dbtInsert(bp, hcard)) != DBT_OK) { 
+      guwError(status);
+      gulCloseListWin(bp);
+      return;
+   }
+   
+   if (strcmp(cp->cd->mainkey, hcard->mainkey) != 0){
+      XtFree(cp->cd->mainkey);
+      cp->cd->mainkey = glbNewString(hcard->mainkey);
+      }
+
+   /* update node in list window with new card */
+   if (gulListWinExists(bp)) {
+      if ((status = dbtCardListInsert(&cl,hcard,bp->sortedby)) != DBT_OK)  
+	 guwError(status);
+      /* replace "new" list with not existent old */
+      bp->lw->cardLst = NULL;
+      if ((status = gulReplaceListData(bp, cl)) != OK) {
+	 guwError(status);
+	 gulCloseListWin(bp);
+      }
+   } /* endif */
+
+   bp->changed = TRUE;
+   cp->changed = FALSE;
+   cp->new = TRUE;
+   
+   if (cp->extended){
+      XtDestroyWidget(cp->cw->usrFldVport);
+      XtResizeWidget(cp->cw->cardShell, cp->cw->width, cp->cw->height,
+	 cp->cw->borderWidth);
+      }
+   cp->extended=FALSE;
+
+   textblock.firstPos = 0;
+   textblock.length = 0;
+   textblock.ptr = NULL;
+   textblock.format = FMT8BIT;
+
+   XawTextReplace(cwp->mainkey, (XawTextPosition) 0, 
+          (XawTextPosition) strlen(cp->cd->mainkey),
+          (XawTextBlock *) &textblock);
+   XawTextSetInsertionPoint(cwp->mainkey, (XawTextPosition) 0);
+   XtVaGetValues(cwp->mainkey, XtNstring, &str, NULL);
+   for (i=0;i<max_fields;i++){
+      if (cwp->wfield[2*i+1]){
+         tbl[i].firstPos = 0;
+         tbl[i].length = 0;
+         tbl[i].ptr = NULL;
+         tbl[i].format = FMT8BIT;
+
+         XawTextReplace(cwp->wfield[2*i+1], (XawTextPosition) 0, 
+             (XawTextPosition) strlen(cp->cd->field[i]),
+             (XawTextBlock *) &(tbl[i]));
+         XawTextSetInsertionPoint(cwp->wfield[2*i+1], (XawTextPosition) 0);
+         XtVaGetValues(cwp->wfield[2*i+1], XtNstring, &str, NULL);
+	 }
+      }
+
+   dbtDeleteCard(&hcard);
+
+   if (cp->aw != NULL)
+      annoteClose(cp);
+   /* create new internal data for a card window */
+   type=cp->cd->cardtype;
+   dbtDeleteCard(&(cp->cd));
+   if ((status = dbtMakeCard(&(cp->cd))) != DBT_OK) {
+      guwError(status);
+      return;
+   }
+   cp->aw=NULL;
+   cp->cd->cardtype = type;
+   if ((cp->cd->cardtypestr = glbNewString(glbTypeToName(type))) == NULL) {
+      guwError(ERR_NOMALLOC);
+      dbtDeleteCard(&cp->cd);
+      return;
+      }
+   
+   if (cotFocus()){
+      for (i=0;i<max_fields;i++){
+         if (cwp->wfield[2*i+1]){
+           XtVaSetValues(cwp->wfield[2*i+1], XtNborderColor, fore, NULL);
+         }
+      } 
+      XtVaSetValues(cwp->mainkey, XtNborderColor, focus, NULL);
+      XtSetKeyboardFocus(cp->cw->cardFlds, cwp->mainkey);
+   }
+   XtRemoveAllCallbacks(cp->cw->change, XtNcallback);
+   XtRemoveAllCallbacks(cp->cw->next, XtNcallback);
+   XtAddCallback(cp->cw->change, XtNcallback, ccdSaveCardCmd, (XtPointer)cp);
+   XtAddCallback(cp->cw->next, XtNcallback, ccdNextCardCmd, (XtPointer)cp);
+
+}
+
 /*********************************************************************/
 /* ccdSaveCardCmd:                                                   */
 /*    Callback function for command "Save" in card window            */
@@ -169,6 +515,7 @@ String str;
       }
 
    cp->changed = FALSE;
+   cp->new = FALSE;
    bp->changed = TRUE;
 
    /* insert card in list of cards for list window */
@@ -187,7 +534,9 @@ String str;
    /* Change callback to change */
    dbtDeleteCard(&hcard);
    XtRemoveAllCallbacks(cp->cw->change, XtNcallback);
+   XtRemoveAllCallbacks(cp->cw->next, XtNcallback);
    XtAddCallback(cp->cw->change, XtNcallback, ccdChangeCardCmd, (XtPointer)cp);
+   XtAddCallback(cp->cw->next, XtNcallback, ccdNextChangeCmd, (XtPointer)cp);
 }
 
 
@@ -310,6 +659,15 @@ String hlpstring;
       sprintf(aw->shellName, "%s: NEW", glbFldToName(nannote));
    else
       sprintf(aw->shellName, "%s: %s", glbFldToName(nannote), cp->cd->mainkey);
+   #ifdef ACTION_PROBLEM
+   if (first_in){
+   #endif
+   XtAppAddActions(XtWidgetToApplicationContext(topLevel), annote_actions,
+		  XtNumber(annote_actions));
+   #ifdef ACTION_PROBLEM
+   first_in = 0;
+   }
+   #endif
    aw->annoteShell = XtVaCreatePopupShell("AnnoteShell",
 	       topLevelShellWidgetClass, topLevel,
 	       XtNtitle, aw->shellName,
@@ -329,7 +687,7 @@ String hlpstring;
                     commandWidgetClass, aw->cmdBox, NULL);
    aw->close     = XtVaCreateManagedWidget("close",
                     commandWidgetClass, aw->cmdBox, NULL);
-   cwp->annote = XtVaCreateManagedWidget("AnnoteText",
+   cwp->annote = XtVaCreateManagedWidget("annoteText",
 		    asciiTextWidgetClass, aw->annoteWin,
 		    XtNtype, XawAsciiString,
 		    XtNeditType, XawtextEdit, 
@@ -674,6 +1032,7 @@ ccdCloseCardCmd (Widget w, XtPointer clientData, XtPointer callData)
 CardPtr cp = (CardPtr)clientData;
 
    ccdCloseCard(cp->bp, cp);
+   XtUninstallTranslations(w);
 }
 
 
@@ -706,6 +1065,65 @@ Errcode status;
 }
 
 
+/*********************************************************************/
+/* ccdOpenCrossrefCmd:                                               */
+/*    Callback function for command "Crossref" in card window        */
+/*********************************************************************/
+void 
+ccdOpenCrossrefCmd (Widget w, XtPointer clientData, XtPointer callData)
+{
+CardPtr cp = (CardPtr)clientData;
+CardPtr cp2;
+Errcode status;
+String s;
+CardData *wcCard = NULL;
+CardListNode *cl = NULL;
+
+BibPtr p = cp->bp;
+   
+   /* make search card */
+   if ((status = (int)dbtMakeCard(&wcCard)) != OK) {
+     guwError(status);
+     return;
+   }
+   s = cp->cd->field[ncrossref];
+   if (glbIsStringEmpty(s) == 1){
+      guwNotice(ERR_CROSSEMPTY);
+      return;
+   }
+   wcCard->mainkey = glbNewString(s);
+   if ((status = dbtSearch(p->treeIdx, &wcCard, &cl))!=OK){
+      guwError(status);
+      return;
+      }
+   dbtDeleteCard(&wcCard);
+
+   if (cl == NULL) {
+      guwError(ERR_CROSSNOTFOUND);
+      return;
+   }
+   
+   if ((cp2 = glbFindCard(p, cl->data)) != NULL) {
+      if (XtIsRealized(cp2->cw->cardShell)) {
+	 XRaiseWindow(XtDisplay(cp2->cw->cardShell),
+		      XtWindow(cp2->cw->cardShell));
+      }
+      return;
+   }
+
+   if ((status = glbNewCardListEl(p, &cp2, cl->data)) != OK) {
+      guwError(status);
+      return;
+   }
+
+   dbtCardListDelete(&cl);
+
+   if ((status = gucOpenCardWin(p, cp2, FALSE)) != OK)
+      guwError(status);
+
+}
+
+
 /*********************************************************************/
 /* LOCAL FUNCTIONS                                                   */
 /*********************************************************************/
