@@ -24,6 +24,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
 #include <X11/Intrinsic.h> 
 
 #ifndef __hpux
@@ -830,6 +831,7 @@ Errcode dbtDeleteAllUserFld(UserFld **list)
 int   dbtSearchUserFld(UserFld **list, UserFld **reglist)
 {
  UserFld *h, *hreg;
+ char *hfield;
  int gef;
 
  hreg = *reglist;
@@ -839,10 +841,19 @@ int   dbtSearchUserFld(UserFld **list, UserFld **reglist)
   h = *list;
   while (h) {
    if (strcmp(hreg->fldName, h->fldName)==0){
-     if (!step(h->fldData, hreg->fldData))
+     if (cotIgnoreCase())
+        hfield = strupr(strdup(h->fldData));
+     else
+        hfield = h->fldData;
+     if (!step(hfield, hreg->fldData)){
+       if (cotIgnoreCase())
+ 	  XtFree(hfield);
         return 0;
+        }
      else 
 	gef = 1;
+     if (cotIgnoreCase())
+	XtFree(hfield);
      }
    h = h->next;
    }
@@ -864,11 +875,21 @@ int   dbtSearchUserFld(UserFld **list, UserFld **reglist)
 int dbtSearchAllUserFld(UserFld **list, char *str)
 {
  UserFld *h;
+ char *hfield;
 
  h = *list;
  while (h) {
-   if (step(h->fldData, str)) 
+   if (cotIgnoreCase())
+      hfield = strupr(strdup(h->fldData));
+   else
+      hfield = h->fldData;
+   if (step(hfield, str)){
+     if (cotIgnoreCase())
+	XtFree(hfield);
      return 1;
+     }
+   if (cotIgnoreCase())
+      XtFree(hfield);
    h = h->next;
  }
  return 0; 
@@ -1310,8 +1331,8 @@ int datecmp(CardData *c1, CardData *c2, int fieldnr)
  if (hs1==NULL) return -1;
  hs2 = c2->field[fieldnr];
  if (hs2==NULL) return 1;
- while (isspace(*hs1)) hs1++;
- while (isspace(*hs2)) hs2++;
+ while (isspace(*hs1) || (*hs1=='"') || (*hs1=='{')) hs1++;
+ while (isspace(*hs2) || (*hs2=='"') || (*hs2=='{')) hs2++;
  if (strlen(hs1) < 10) return -1;
  if (strlen(hs2) < 10) return 1;
  erg = strcmp(hs1+6, hs2+6);
@@ -1498,7 +1519,7 @@ Errcode dbtDelete(int treeIdx, CardData *card, int *deleted)
 Errcode MakeRegCard(CardData *card, CardData *reg)
 {
  int length;
- char *endbuf, *erg;
+ char *endbuf, *erg, *hfield;
  UserFld *helpufield = NULL;
  UserFld *ufzeiger = NULL;
  FieldName i;
@@ -1506,39 +1527,67 @@ Errcode MakeRegCard(CardData *card, CardData *reg)
 if (card->mainkey != NULL) {
    reg->mainkey = (String)XtCalloc(1,MAXREGSIZE);
    endbuf = reg->mainkey + MAXREGSIZE + 1;
-   erg = compile(card->mainkey, reg->mainkey, endbuf, '\0');
+   if (cotIgnoreCase())
+      hfield = strupr(strdup(card->mainkey));
+   else
+      hfield = card->mainkey;
+   erg = compile(hfield, reg->mainkey, endbuf, '\0');
    if (erg == NULL) return DBT_ECOMP;
    length = erg - reg->mainkey + 1;
    erg = (char *)XtRealloc(reg->mainkey, length);
    reg->mainkey = erg;
+   if (cotIgnoreCase()){
+      XtFree(hfield);
+      }
    }
 if (card->cardtypestr != NULL) {
    reg->cardtypestr = (String)XtCalloc(1,MAXREGSIZE);
    endbuf = reg->cardtypestr + MAXREGSIZE + 1;
-   erg = compile(card->cardtypestr, reg->cardtypestr, endbuf, '\0');
+   if (cotIgnoreCase())
+      hfield = strupr(strdup(card->cardtypestr));
+   else
+      hfield = card->cardtypestr;
+   erg = compile(hfield, reg->cardtypestr, endbuf, '\0');
    if (erg == NULL) return DBT_ECOMP;
    length = erg - reg->cardtypestr + 1;
    erg = (char *)XtRealloc(reg->cardtypestr, length);
    reg->cardtypestr = erg;
+   if (cotIgnoreCase()){
+      XtFree(hfield);
+      }
    }
 if (card->authorsort != NULL) {
    reg->authorsort = (String)XtCalloc(1,MAXREGSIZE);
    endbuf = reg->authorsort + MAXREGSIZE + 1;
-   erg = compile(card->authorsort, reg->authorsort, endbuf, '\0');
+   if (cotIgnoreCase())
+      hfield = strupr(strdup(card->authorsort));
+   else
+      hfield = card->authorsort;
+   erg = compile(hfield, reg->authorsort, endbuf, '\0');
    if (erg == NULL) return DBT_ECOMP;
    length = erg - reg->authorsort + 1;
    erg = (char *)XtRealloc(reg->authorsort, length);
    reg->authorsort = erg;
+   if (cotIgnoreCase()){
+      XtFree(hfield);
+      }
    }
 for (i=0; i<=max_fields; i++){
   if (card->field[i] != NULL) {
-     reg->field[i] = (String)XtCalloc(1,MAXREGSIZE);
+     reg->field[i] = (String) XtCalloc(1,MAXREGSIZE);
      endbuf = reg->field[i] + MAXREGSIZE + 1;
-     erg = compile(card->field[i], reg->field[i], endbuf, '\0');
+     if (cotIgnoreCase())
+	hfield = strupr(strdup(card->field[i]));
+     else
+	hfield = card->field[i];
+     erg = compile(hfield, reg->field[i], endbuf, '\0');
      if (erg == NULL) return DBT_ECOMP;
      length = erg - reg->field[i] + 1; 
      erg = (char *)XtRealloc(reg->field[i], length); 
      reg->field[i] = erg;
+     if (cotIgnoreCase()){
+	XtFree(hfield);
+        }
      }
 }
 
@@ -1549,12 +1598,19 @@ if (card->ufield != NULL) {
     reg->ufield->fldName = glbNewString(ufzeiger->fldName);
     reg->ufield->fldData = (String)XtCalloc(1,MAXREGSIZE);
     endbuf = reg->ufield->fldData + MAXREGSIZE + 1;
-    erg = compile(ufzeiger->fldData, reg->ufield->fldData, endbuf, '\0');
+    if (cotIgnoreCase())
+       hfield = strupr(strdup(ufzeiger->fldData));
+    else
+       hfield = ufzeiger->fldData;
+    erg = compile(hfield, reg->ufield->fldData, endbuf, '\0');
     if (erg == NULL) return DBT_ECOMP;
     length = erg - reg->ufield->fldData + 1; 
     erg = (char *)XtRealloc(reg->ufield->fldData, length);  
     reg->ufield->fldData = erg; 
     ufzeiger = ufzeiger->next;
+    if (cotIgnoreCase()){
+       XtFree(hfield);
+       }
     }
 
 if (ufzeiger != NULL) {
@@ -1563,11 +1619,18 @@ if (ufzeiger != NULL) {
     reg->ufield->next->fldName = glbNewString(ufzeiger->fldName);
     reg->ufield->next->fldData = (String)XtCalloc(1,MAXREGSIZE);
     endbuf = reg->ufield->next->fldData + MAXREGSIZE + 1;
-    erg = compile(ufzeiger->fldData, reg->ufield->next->fldData, endbuf, '\0');
+    if (cotIgnoreCase())
+       hfield = strupr(strdup(ufzeiger->fldData));
+    else
+       hfield = ufzeiger->fldData;
+    erg = compile(hfield, reg->ufield->next->fldData, endbuf, '\0');
     if (erg == NULL) return DBT_ECOMP;
     length = erg - reg->ufield->next->fldData + 1; 
     erg = (char *)XtRealloc(reg->ufield->next->fldData, length);  
     reg->ufield->next->fldData = erg; 
+    if (cotIgnoreCase()){
+       XtFree(hfield);
+       }
     }
  return DBT_OK;
 }
@@ -1582,27 +1645,46 @@ Errcode RegCompCard(CardData *card, CardData *reg)
 {
  int flag, nbOfComp;
  FieldName i;
+ char *hfield;
 
  nbOfComp = 0;
 
  if (reg->authorsort) { 
    flag = 0;
    if (!flag && (card->mainkey)) {
-     if (step(card->mainkey, reg->authorsort))
+     if (cotIgnoreCase())
+        hfield = strupr(strdup(card->mainkey));
+     else
+        hfield = card->mainkey;
+     if (step(hfield, reg->authorsort))
         flag = 1;
      nbOfComp++;
+     if (cotIgnoreCase())
+        XtFree(hfield);
    }
    if (!flag && (card->cardtypestr)) {
-     if (step(card->cardtypestr, reg->authorsort))
+     if (cotIgnoreCase())
+        hfield = strupr(strdup(card->cardtypestr));
+     else
+        hfield = card->cardtypestr;
+     if (step(hfield, reg->authorsort))
         flag = 1;
      nbOfComp++;
+     if (cotIgnoreCase())
+        XtFree(hfield);
    }
    for (i=0; i<max_fields; i++) {
       if (!flag && card->field[i]) {
-        if (step(card->field[i], reg->authorsort))
+        if (cotIgnoreCase())
+           hfield = strupr(strdup(card->field[i]));
+        else
+           hfield = card->field[i];
+        if (step(hfield, reg->authorsort))
 	   flag = 1;
         nbOfComp++;
         }
+        if (cotIgnoreCase())
+           XtFree(hfield);
       }
    if (!flag)
       flag = dbtSearchAllUserFld(&card->ufield, reg->authorsort);
@@ -1615,21 +1697,33 @@ Errcode RegCompCard(CardData *card, CardData *reg)
  if (flag  && reg->mainkey) {
    if (!card->mainkey) return DBT_ENOMATCH;
    else {
-     if (step(card->mainkey, reg->mainkey)) 
+     if (cotIgnoreCase())
+        hfield = strupr(strdup(card->mainkey));
+     else
+        hfield = card->mainkey;
+     if (step(hfield, reg->mainkey)) 
         flag = 1; 
      else 
         flag = 0;
      nbOfComp++;
+     if (cotIgnoreCase())
+        XtFree(hfield);
    }
  }
  if (flag  && reg->cardtypestr) {
    if (!card->cardtypestr) return DBT_ENOMATCH;
    else {
-     if (step(card->cardtypestr, reg->cardtypestr)) 
+     if (cotIgnoreCase())
+        hfield = strupr(strdup(card->cardtypestr));
+     else
+        hfield = card->cardtypestr;
+     if (step(hfield, reg->cardtypestr)) 
         flag = 1; 
      else 
         flag = 0;
      nbOfComp++;
+     if (cotIgnoreCase())
+        XtFree(hfield);
    }
  }
 
@@ -1637,11 +1731,17 @@ Errcode RegCompCard(CardData *card, CardData *reg)
     if (flag  && reg->field[i]) {
       if (!card->field[i]) return DBT_ENOMATCH;
       else {
-         if (step(card->field[i], reg->field[i])) 
+         if (cotIgnoreCase())
+  	    hfield = strupr(strdup(card->field[i]));
+         else
+	    hfield = card->field[i];
+         if (step(hfield, reg->field[i])) 
 	    flag = 1; 
          else 
 	    flag = 0;
          nbOfComp++;
+         if (cotIgnoreCase())
+  	    XtFree(hfield);
       }
     }
  }
@@ -1964,10 +2064,9 @@ char *mystrcat(char *str1, char *str2)
     return(str1);
     }
 
-
 /*********************************************************************/
-/* void get_name(CardData *c1, int fieldnr)                          */
-/* c1->authorsort wird besetzt, und zwar im Format nnvv              */
+/* void get_name(CardData *card, int fieldnr)                        */
+/* card->authorsort wird besetzt, und zwar im Format nnvv            */
 /*********************************************************************/
 void get_name(CardData  *card, int fieldnr)
    
@@ -1975,10 +2074,12 @@ void get_name(CardData  *card, int fieldnr)
     char *semicolon = ";";
     char *comma = ",";
     char *andstr = "and";
-    char *name[10];
+    char *name[11];
     char *entry, *p_surname, *p_firstname, *hname;
     int  i,j,k;
     int inbracket = 0;
+    int daz = 0;
+    int first;
    
     if (card->field[fieldnr]==NULL)
        return;
@@ -1995,11 +2096,18 @@ void get_name(CardData  *card, int fieldnr)
 	 }
       else if (entry[i] == '}')
 	 inbracket--;
+      else if ((entry[i] == '"') && (inbracket == 0))
+	 daz = !daz;
       else if (entry[i] == ';')
          entry[i] = ' ';
-      else if ((entry[i] == ',') && (inbracket>0))
+      else if ((entry[i] == ',') && (inbracket>0) && (!cotOrig()))
          entry[i] = ' ';
-      else if (!strncmp(&entry[i],andstr,3) && inbracket==0)
+      else if ((entry[i] == ',') && ((inbracket>1)||
+	       ((inbracket==1) && daz)) && (cotOrig()))
+         entry[i] = ' ';
+      else if (!strncmp(&entry[i],andstr,3) && 
+	       ((inbracket==0) || 
+	        ((daz==0) && (inbracket == 1) && cotOrig()))) 
        if ((i>=1) && (i<(strlen(entry)-3)) && isspace(entry[i-1]) && 
 	    isspace(entry[i+3])){
 	entry[i++] = ' ';
@@ -2021,11 +2129,22 @@ void get_name(CardData  *card, int fieldnr)
        if (strchr (name[j], ',') == NULL)
           {
            /* there is NO comma at all */
+	   first = 0;
+	   daz = 0;
 	   hname = name[j];
            for (k=strlen(hname)-1; isspace(hname[k])&&(k>=0); k--);
            for (; k>=0; k--)
-	     {if (hname[k] == '}') 
+	     {if ((hname[k] == '"') && (cotOrig()) && 
+			 (daz==0) && (inbracket == 0) && !first) 
+		daz=1;
+	      else if ((hname[k] == '}') && (!cotOrig()))
 		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && daz))
+		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && first))
+		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && !first))
+		first = 1;
 	      else if (hname[k] == '{') 
 		inbracket--;
               else if (inbracket>0);
@@ -2049,3 +2168,4 @@ void get_name(CardData  *card, int fieldnr)
    XtFree(entry);
    }
 
+
