@@ -92,7 +92,7 @@ char    *mystrcat(char *s1, char *s2);
 int     dbtSearchAllUserFld(UserFld **list, regex_t *str);
 int     dbtSearchUserFld(UserFld **list, UserFld **reglist);
 Boolean Insert(int treeIdx, AvlNode **tree, CardData *card, int *h);
-Boolean Search(AvlNode *tree, CardData **card);
+Boolean Search(AvlNode *baum, CardData **card, CardListNode **list);
 Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted);
 Errcode MakeListNode(ListNode **list);
 Errcode ListAppend(ListNode **list, String word);
@@ -719,28 +719,30 @@ Boolean Delete(int treeIdx, AvlNode **tree, CardData *card, int *deleted)
  * Returns: TRUE     the node was found
  *          FALSE    the node was not found
  */
-Boolean Search(AvlNode *tree, CardData **card)
+Boolean Search(AvlNode *baum, CardData **card, CardListNode **list)
 {
     int result;
+    CardData *tree;
 
-    if (tree == NULL) {
+    if (baum == NULL) {
         /*
          * at leaf, so key was not in the tree
          */
         return FALSE;
     }
-    else if 
-    ((result = KeyCompare((*card)->mainkey, tree->data->mainkey)) < 0) {
-        return (Search(tree->left, card));
+    if 
+    ((result = KeyCompare((*card)->mainkey, baum->data->mainkey)) < 0) {
+        return (Search(baum->left, card, list));
     }
     else if (result > 0) {
-        return (Search(tree->right, card));
+        return (Search(baum->right, card, list));
     }
     else {
         /*
          * key found
          */
-        CopyCard(card, tree->data);
+        tree = baum->data;
+	dbtCardListInsert(list, tree, SORT_UNSRT);  
         return TRUE;
     }
 }
@@ -1321,10 +1323,13 @@ void get_name(CardData  *card, int fieldnr)
     char *semicolon = ";";
     char *comma = ",";
     char *andstr = "and";
-    char *name[10];
+    char *name[11];
     char *entry, *p_surname, *p_firstname, *hname;
     int  i,j,k;
     int inbracket = 0;
+    int daz = 0;
+    int first;
+
    
     if (card->field[fieldnr]==NULL)
        return;
@@ -1341,11 +1346,18 @@ void get_name(CardData  *card, int fieldnr)
 	 }
       else if (entry[i] == '}')
 	 inbracket--;
+      else if ((entry[i] == '"') && (inbracket == 0))
+	 daz = !daz;
       else if (entry[i] == ';')
          entry[i] = ' ';
-      else if ((entry[i] == ',') && (inbracket>0))
+      else if ((entry[i] == ',') && (inbracket>0) && (!cotOrig()))
          entry[i] = ' ';
-      else if (!strncmp(&entry[i],andstr,3) && inbracket==0)
+      else if ((entry[i] == ',') && ((inbracket>1)||
+	       ((inbracket==1) && daz)) && (cotOrig()))
+         entry[i] = ' ';
+      else if (!strncmp(&entry[i],andstr,3) && 
+	       ((inbracket==0) || 
+	        ((daz==0) && (inbracket == 1) && cotOrig()))) 
        if ((i>=1) && (i<(strlen(entry)-3)) && isspace(entry[i-1]) && 
 	    isspace(entry[i+3])){
 	entry[i++] = ' ';
@@ -1366,12 +1378,22 @@ void get_name(CardData  *card, int fieldnr)
       {
        if (strchr (name[j], ',') == NULL)
           {
-           /* there is NO comma at all */
+	   first = 0;
+	   daz = 0;
 	   hname = name[j];
            for (k=strlen(hname)-1; isspace(hname[k])&&(k>=0); k--);
            for (; k>=0; k--)
-	     {if (hname[k] == '}') 
+	     {if ((hname[k] == '"') && (cotOrig()) && 
+			 (daz==0) && (inbracket == 0) && !first) 
+		daz=1;
+	      else if ((hname[k] == '}') && (!cotOrig()))
 		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && daz))
+		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && first))
+		inbracket++;
+	      else if ((hname[k] == '}') && (cotOrig() && !first))
+		first = 1;
 	      else if (hname[k] == '{') 
 		inbracket--;
               else if (inbracket>0);
@@ -1380,19 +1402,19 @@ void get_name(CardData  *card, int fieldnr)
            mystrcat (card->authorsort, &hname[k+1]);
 	   if (k>0){
              hname[k] = '\0';
-             mystrcat (card->authorsort, hname);
+             mystrcat (card->authorsort, hname); 
 	     }
            }
        else
           {
-           /* get firstname and surname in right order */
            p_surname = (char *) strtok (name[j], comma);
            p_firstname = (char *) strtok (NULL, comma);
            mystrcat (card->authorsort, p_surname);
            mystrcat (card->authorsort, p_firstname);
           }
        }
-   XtFree(entry);
+   XtFree((char *)entry);  
+   return;
    }
 
 
@@ -1449,8 +1471,8 @@ int datecmp(CardData *c1, CardData *c2, int fieldnr)
  if (hs1==NULL) return -1;
  hs2 = c2->field[fieldnr];
  if (hs2==NULL) return 1;
- while (isspace(*hs1)) hs1++;
- while (isspace(*hs2)) hs2++;
+ while (isspace(*hs1) || (*hs1=='"') || (*hs1=='{')) hs1++;
+ while (isspace(*hs2) || (*hs2=='"') || (*hs2=='{')) hs2++;
  if (strlen(hs1) < 10) return -1;
  if (strlen(hs2) < 10) return 1;
  erg = strcmp(hs1+6, hs2+6);
@@ -1493,8 +1515,8 @@ int yearcmp(CardData *c1, CardData *c2)
  if (c2->field[nyear] == NULL) return 1;
  hs1 = c1->field[nyear];
  hs2 = c2->field[nyear];
- if (*hs1=='@') hs1++;
- if (*hs2=='@') hs2++;
+ while (isspace(*hs1) || (*hs1=='"') || (*hs1=='{') || (*hs1=='@')) hs1++;
+ while (isspace(*hs2) || (*hs2=='"') || (*hs2=='{') || (*hs2=='@')) hs2++;
  erg = strcmp(hs1, hs2);
  return erg;
 }
@@ -1622,7 +1644,7 @@ Errcode dbtInsert(BibPtr bp, CardData *card)
 
 
 /*********************************************************************/
-/* Errcode dbtDelete(int treeIdx, CardData *card):                   */
+/* Errcode dbtDelete(int treeIdx, CardData *card, int*deleted):      */
 /* card wird aus dem AVL-Baum mit dem Index treeIdx geloescht        */
 /*********************************************************************/
 
@@ -1793,16 +1815,15 @@ Errcode RegCompCard(CardData *card, CardData *reg)
 
 
 /*********************************************************************/
-/* Errcode dbtSearch(int treeIdx, CardData **card)                   */
-/* eine Karte mit bestimmten Schluessel suchen                       */
+/* Errcode dbtSearch(int treeIdx, CardData **card,                   */
+/*		     CardListNode **list)                            */
+/* eine Karte mit bestimmtem Schluessel suchen und in Liste          */
+/* einfuegen                                                         */
 /*********************************************************************/
-Errcode dbtSearch(int treeIdx, CardData **card)
+Errcode dbtSearch(int treeIdx, CardData **card, CardListNode **list)
 {
-  Boolean erg;
-
-  erg = Search(TreeRoots[treeIdx], card);
-  if (erg) return DBT_OK;
-  else     return DBT_ENONODE;
+  Search(TreeRoots[treeIdx], card, list);
+  return DBT_OK;
 } 
 
 
@@ -2005,13 +2026,14 @@ Errcode dbtCardListInsert(CardListNode **list, CardData *card, int sortedby)
   }
   else {
     vorg = NULL;
-    while  (hlist != NULL)
+    while  (hlist != NULL){
        if (Compare(hlist->data, card, sortedby)<=0){
           vorg = hlist;
           hlist = hlist->next;
 	  }
        else
 	  break;
+    }
     erg = MakeCardListNode(&newlist);
     CopyCard(&newlist->data, card);
     newlist->next = hlist;
