@@ -28,6 +28,8 @@
 #include <X11/Xaw/SimpleMenu.h>
 #include <X11/Xaw/SmeBSB.h>
 #include <X11/Xaw/SmeLine.h>
+#include <X11/Xaw/Text.h>
+#include <X11/Xaw/AsciiText.h>
 #include "bibview.h"
 
 
@@ -100,9 +102,15 @@ CollapsePath(in, out)
      char *in, *out;
 {
     char *p = in, *q = out, *pend = p + strlen(p);
-    
+    int  punkt;
+
+    punkt = 1;
+   
     while (p < pend)
     {
+	if ((*p != '.') && (*p != '/'))
+	   punkt = 0;
+
 	if (*p != '/')
 	{
 	    *q++ = *p++;
@@ -119,10 +127,13 @@ CollapsePath(in, out)
 	else if ( (p + 3 == pend && *(p + 1) == '.' && *(p + 2) == '.') ||
 		 (p + 3 < pend && *(p + 1) == '.'
 		                      && *(p + 2) == '.' && *(p + 3) == '/') )
-	{
-	    while (q > out && *--q != '/')
+	{   if (punkt == 0){
+	       while (q > out && *--q != '/')
 		;
-	    p += 3;
+	       p += 3;
+	       }
+            else
+	       *q++ = *p++;
 	}
 	else
 	{
@@ -540,7 +551,7 @@ char tmpfile[MAX_FILEPATHLEN];
            i++;
            sprintf(tmpfile, "%s.bak.%d", path, i);
            }
-   sprintf(sysStr, "cp -f %s %s.bak.%d", path, path, i);
+   sprintf(sysStr, "cp %s %s.bak.%d", path, path, i);
    if (access(path, F_OK) == 0) {
       system(sysStr);
       return(OK);
@@ -777,25 +788,31 @@ CardPtr cp = NULL;
 
 /***************************************************
  * Test whether file contains non ASCII characters *
+ * RETURNS:   0  file is OK                        *
+ *            1  file couldn't be opened           *
+ *            2  file contains illegal char        *
  ***************************************************/
 int glbContIllegalChar(char *dateiName)
 {
  FILE *dptr;
  int inh;
 
+ return 0;
+/*
  dptr = fopen(dateiName, "r");
 
  if (dptr == NULL)
-   return 0;
+   return 1;
 
  while ( ((inh = getc(dptr)) != EOF) && isascii(inh) ) ;
    
  fclose(dptr); 
  
  if (inh == EOF)
-   return 1;
- else 
    return 0;
+ else 
+   return 2;
+   */
 }
 
 /*********************************************************************/
@@ -816,6 +833,7 @@ CardList p;
    return(NULL);
 }
 
+
 /*********************************************************************/
 /* glbCreateTypeMenu:                                                */
 /*    Build pulldown menus with card types                           */
@@ -876,3 +894,89 @@ char name[8];
    }
 }
 
+/*********************************************************************/
+/* string_event                                                      */
+/*                                                                   */
+/*********************************************************************/
+void string_event(w, event, params, nparams)
+    Widget w;
+    XEvent *event;
+    String *params;
+    Cardinal *nparams;
+{
+    XawTextBlock textblock;
+    XawTextPosition textins;
+    char *textstr = *params;
+    int i;
+    int len;
+    
+    if (!((strcmp(XtName(w),"field")==0) ||
+       (strcmp(XtName(w),"annoteText")==0) ||
+       (strcmp(XtName(w),"userFieldL")==0) ||
+       (strcmp(XtName(w),"userField")==0))) return;
+    if (*nparams != 1) return;
+
+    if ((*params)[0] == '0' && (*params)[1] == 'x' && (*params)[2] != '\0') {
+        char c, *p, hexval[2];
+        hexval[0] = hexval[1] = 0;
+	textstr="";
+        for (p = *params+2; (c = *p); p++) {
+            hexval[0] *= 16;
+            if (isupper(c)) c = tolower(c);
+            if (c >= '0' && c <= '9')
+                hexval[0] += c - '0';
+            else if (c >= 'a' && c <= 'f')
+                hexval[0] += c - 'a' + 10;
+            else break;
+        }
+        if (c == '\0' && isascii(hexval[0])) 
+            textstr = hexval;
+    }
+  	
+    textins = XawTextGetInsertionPoint(w);
+    textblock.firstPos = 0;
+    textblock.length = 0;
+    textblock.ptr = NULL;
+    textblock.format = FMT8BIT;
+    len = strlen(textstr);
+    textblock.ptr =  textstr;
+    textblock.length += len;
+    
+    XawTextReplace(w, (XawTextPosition) textins, 
+	    (XawTextPosition) textins,
+	    (XawTextBlock *) &textblock);
+    XawTextSetInsertionPoint(w, textins+len);
+}
+
+/*********************************************************************/
+/* getCardPtr                                                        */
+/*     gets CardPtr from widget                                      */
+/*********************************************************************/
+CardPtr getCardPtr(Widget w)
+{
+ BibPtr bp;
+ CardPtr cp;
+ CardWidgetsPtr cwp;
+ int i;
+
+ bp = glbFirstBibListEl();
+ while (bp!=NULL){
+    cp = glbFirstCardListEl(bp);
+    while (cp!=NULL){
+       cwp = &cp->cw->ct.cw;
+       if (w == cwp->mainkey)
+          return(cp);
+       if (w == cwp->owntype)
+          return(cp);
+       if (w == cwp->annote)
+          return(cp);
+       for (i=0; i< MAX_FIELDS; i++){
+         if (w == cwp->wfield[2*i+1])
+	    return(cp);
+         }
+       cp = glbNextCardListEl(bp,cp);
+       }
+    bp = glbNextBibListEl(bp);
+    }
+}
+
