@@ -1,3 +1,4 @@
+
 /*********************************************************************/
 /*  bibView: Administration of BibTeX-Databases                      */
 /*           (Verwaltung von BibTeX-Literaturdatenbanken)            */
@@ -65,27 +66,115 @@ extern char sort_field[];
 
 /* local global variables */
 /* ------------------------- */
-static XtTranslations trans;
-static Pixel back, fore, focus;
+Pixel back, fore, focus, reqback, auth_ed_back;
 
-static char trans_string[] =
-   "<Key>Tab:   forward_focus()\n\
-   <Key>Escape: backward_focus()\n\
-   <Btn3Down>,<Btn3Up>: set_focus()";
 
+extern void string_event();
+extern CardPtr getCardPtr();
 static void forward_focus();
 static void backward_focus();
 static void set_focus();
+static void close_card();
+static void next_card();
+static void save_card();
+static void save_close_card();
 
 static XtActionsRec actions[] = {
    "forward_focus", forward_focus,
    "backward_focus", backward_focus,
    "set_focus", set_focus,
+   "string", string_event,
+   "close", close_card,
+   "next", next_card,
+   "save", save_card,
+   "saveclose", save_close_card
 };
 
 #ifdef ACTION_PROBLEM
 static int first_in = 1;
 #endif
+  
+
+/*********************************************************************/
+/* next_card                                                         */
+/*     calls ccdNextCardCmd                                          */
+/*********************************************************************/
+static void next_card(w)
+    Widget w;
+{
+ CardPtr cp;
+
+ if (strcmp(XtName(w),"field")!=0) return;
+ cp = getCardPtr(w);
+ if (cp==NULL){
+    return;
+ }
+ if (cp->new)
+    ccdNextCardCmd(w, (XtPointer)cp, NULL);
+ else
+    ccdNextChangeCmd(w, (XtPointer)cp, NULL);
+ }
+
+/*********************************************************************/
+/* close_card                                                        */
+/*     calls ccdCloseCardCmd                                         */
+/*********************************************************************/
+static void close_card(w)
+    Widget w;
+{
+ CardPtr cp;
+
+ if (strcmp(XtName(w),"field")!=0) return;
+ cp = getCardPtr(w);
+ if (cp==NULL){
+    return;
+ }
+ ccdCloseCardCmd(w, (XtPointer)cp, NULL);
+ }
+
+
+/*********************************************************************/
+/* saveCard                                                          */
+/*     calls ccdSaveCardCmd                                          */
+/*********************************************************************/
+static void save_card(w)
+    Widget w;
+{
+ CardPtr cp;
+
+ if (strcmp(XtName(w),"field")!=0) return;
+ cp = getCardPtr(w);
+ if (cp==NULL){
+    return;
+ }
+ if (cp->new)
+    ccdSaveCardCmd(w, (XtPointer)cp, NULL);
+ else
+    ccdChangeCardCmd(w, (XtPointer)cp, NULL);
+ }
+
+
+/*********************************************************************/
+/* save_close_card                                                   */
+/*     calls ccdSaveCardCmd  and ccdCloseCardCmd                     */
+/*********************************************************************/
+static void save_close_card(w)
+    Widget w;
+{
+ CardPtr cp;
+
+ if (strcmp(XtName(w),"field")!=0) return;
+ cp = getCardPtr(w);
+ if (cp==NULL){
+    return;
+ }
+ if (cp->new)
+    ccdSaveCardCmd(w, (XtPointer)cp, NULL);
+ else
+    ccdChangeCardCmd(w, (XtPointer)cp, NULL);
+ ccdCloseCardCmd(w, (XtPointer)cp, NULL);
+ }
+
 
 /*********************************************************************/
 /* forward_focus:                                                    */
@@ -98,6 +187,8 @@ static void forward_focus(Widget w)
  CardWidgetsPtr cwp;
  int i;
 
+ if (!cotFocus())
+    return;
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
@@ -170,6 +261,8 @@ static void backward_focus(Widget w)
  CardWidgetsPtr cwp;
  int i;
 
+ if (!cotFocus())
+    return;
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
@@ -243,6 +336,8 @@ static void set_focus(Widget w)
  CardWidgetsPtr cwp;
  int i;
 
+ if (!cotFocus())
+    return;
  bp = glbFirstBibListEl();
  while (bp!=NULL){
     cp = glbFirstCardListEl(bp);
@@ -278,16 +373,14 @@ Dimension height;
    #ifdef ACTION_PROBLEM
    if (first_in){
    #endif
-   if (cotFocus()){
-      XtAppAddActions(XtWidgetToApplicationContext(topLevel), actions,
+   XtAppAddActions(XtWidgetToApplicationContext(topLevel), actions,
 		  XtNumber(actions));
-   }
    #ifdef ACTION_PROBLEM
    first_in = 0;
    }
    #endif
-   if (cotFocus())
-      trans = XtParseTranslationTable(trans_string);
+   reqback = options.reqColor;
+   auth_ed_back = options.authedColor;
 
    /* allocate memory for new element of window list */
    if ((cw = (CardWinPtr) XtCalloc(1, sizeof(CardWin))) == NULL) {
@@ -309,7 +402,7 @@ Dimension height;
    sprintf(cw->shellName, "%s: %s", bp->filename, 
 				    cp->cd->cardtypestr);
 
-   /* create popup shell for new file */
+   /* create popup shell fornew file */
    cw->cardShell = XtVaCreatePopupShell("cardShell",
                      topLevelShellWidgetClass, topLevel,
                      XtNtransientFor, bp->bw->bibShell,
@@ -338,6 +431,8 @@ Dimension height;
 	        commandWidgetClass, cw->cmdBox, NULL);
    cw->crossref = XtVaCreateManagedWidget("crossref", 
 	        commandWidgetClass, cw->cmdBox, NULL);
+   cw->next = XtVaCreateManagedWidget("next", 
+	        commandWidgetClass, cw->cmdBox, NULL);
    cw->close = XtVaCreateManagedWidget("quit", 
 	         commandWidgetClass, cw->cmdBox, NULL);
 
@@ -353,6 +448,10 @@ Dimension height;
       XtAddCallback(cw->change, XtNcallback, ccdChangeCardCmd, (XtPointer)cp);
    XtAddCallback(cw->copy, XtNcallback, ccdCopyCardCmd, (XtPointer)cp);
    XtAddCallback(cw->crossref, XtNcallback, ccdOpenCrossrefCmd, (XtPointer)cp);
+   if (isNew)
+      XtAddCallback(cw->next, XtNcallback, ccdNextCardCmd, (XtPointer)cp);
+   else
+      XtAddCallback(cw->next, XtNcallback, ccdNextChangeCmd, (XtPointer)cp);
 
    /* create card window desktop */
    cw->cardDesk = XtVaCreateManagedWidget("carddesk",  
@@ -360,14 +459,13 @@ Dimension height;
 		    XtNshowGrip, True,
 		    XtNallowVert, True,
 		    NULL);
-/*   cw->cardDesk = XtVaCreateManagedWidget("carddesk",  
-	            formWidgetClass, cw->cardWin, NULL); */
    cw->cardFlds = XtVaCreateManagedWidget(glbTypeToName(cp->cd->cardtype), 
 	            formWidgetClass, cw->cardDesk, NULL);
 
    /* set card pointer to new struct, new window created */
    cp->cw = cw;
    cp->aw = NULL;
+   cp->new = isNew;
    bp->noOfCardWins++;
 
    /* Position window near bibliography desktop */
@@ -407,7 +505,7 @@ Dimension height;
 
 
 /*********************************************************************/
-/* gucStdFldsChanged:                                                */
+/* gucAuthorChanged:                                                 */
 /*    Returns true, if user made changes to standard BibTeX fields   */
 /*********************************************************************/
 #define WidgetChanged(w) (XawAsciiSourceChanged(XawTextGetSource(w)))
@@ -433,6 +531,11 @@ int field;
       return(FALSE);
 }
 
+
+/*********************************************************************/
+/* gucStdFldsChanged:                                                */
+/*    Returns true, if user made changes to standard BibTeX fields   */
+/*********************************************************************/
 Boolean
 gucStdFldsChanged (CardPtr cp)
 {
@@ -944,8 +1047,6 @@ int i;
 		  	  XtNtop, XtChainTop, 
 		  	  XtNfromHoriz, cwp->mainkeyL, 
 			  NULL);
-   if (cotFocus())
-      XtOverrideTranslations(cwp->mainkey, trans);
    aktwidget = cwp->mainkey;
    if (cdp->cardtype == MAX_BIBTEX_TYPES){
       cwp->owntypeL = 	XtVaCreateManagedWidget("fieldLabel", 
@@ -958,8 +1059,6 @@ int i;
 		  	  XtNstring, cdp->cardtypestr, 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->owntypeL, NULL);
-      if (cotFocus())
-         XtOverrideTranslations(cwp->owntype, trans);
       aktwidget = cwp->owntype;
    }
    for (i=0; i<max_fields; i++) {
@@ -974,10 +1073,20 @@ int i;
 		  	  XtNstring, cdp->field[i], 
 		    	  XtNfromVert, aktwidget, 
 		  	  XtNfromHoriz, cwp->wfield[2*i], NULL);
-         if (cotFocus())
-            XtOverrideTranslations(cwp->wfield[2*i+1], trans);
-      if (isrequiredfield(i, cdp->cardtype))
+      if (((i == nauthor) || (i == neditor)) &&
+	   ((cdp->cardtype==book) || (cdp->cardtype==inbook))){
          XtVaSetValues(cwp->wfield[2*i+1], XtNborderWidth, 3, NULL);
+         XtVaSetValues(cwp->wfield[2*i+1], XtNbackground, auth_ed_back, NULL);
+	 }
+      else if (((i == nchapter) || (i == npages)) &&
+	   (cdp->cardtype==inbook)){
+         XtVaSetValues(cwp->wfield[2*i+1], XtNborderWidth, 3, NULL);
+         XtVaSetValues(cwp->wfield[2*i+1], XtNbackground, auth_ed_back, NULL);
+	 }
+      else if (isrequiredfield(i, cdp->cardtype)){
+         XtVaSetValues(cwp->wfield[2*i+1], XtNborderWidth, 3, NULL);
+         XtVaSetValues(cwp->wfield[2*i+1], XtNbackground, reqback, NULL);
+	 }
       aktwidget = cwp->wfield[2*i+1];
       }
    }
