@@ -81,13 +81,13 @@ static char *line3   = "Bibliography Window";
 #ifdef GERMAN
 static char *line4   = "Listenfenster";
 #else
-static char *line4   = "List window";
+static char *line4   = "List Window";
 #endif
 
 #ifdef GERMAN
 static char *line5   = "Kartenfenster";
 #else
-static char *line5   = "CardWindow";
+static char *line5   = "Card Window";
 #endif
 
 #ifdef GERMAN
@@ -129,10 +129,7 @@ und Jahr werden gezeigt.\n\
 Das Kartenfenster (card window) (maximal eines pro Eintrag)\n\
 dient zum Editieren der Eintraege. Es enthaelt Boxen fuer alle\n\
 Felder des Eintrags (je nach dem Typ des Eintrags).\n\
-Ein Feld kann editiert werden, wenn sich der Maus-Cursor in der\n\
-entsprechenden Box befindet.\n\
-Makros in Feldern und das Symbol fuer Konkatenation ('#') sind\n\
-durch das Zeichen '@' gekennzeichnet. Die von BibTeX geforderten\n\
+Die von BibTeX geforderten\n\
 Felder sind durch fette Linien markiert.\n\
 Ein Kartenfenster wird nach dem Anklicken des entsprechenden Eintrags\n\
 im Listenfenster (mit der linken Maustaste) oder nach der Auswahl\n\
@@ -206,9 +203,7 @@ entries. It displays the fields author, title, type and year.\n\
 The card window (at most one for every entry) helps editing an \n\
 entry.  It contains boxes for each field of the entry (according \n\
 to the type).\n\
-The fields can be edited by putting the mouse cursor into the field.\n\
-Macros in fields and the symbol for concatenation ('#') are marked\n\
-by a preceding '@'. The required fields are marked by bold lines.\n\
+The required fields are marked by bold lines.\n\
 A card window is displayed after clicking an entry in the list menu\n\
 (left mouse button) or selecting a type in the `New` menu of a\n\
 bibliography window.\n\
@@ -586,7 +581,30 @@ The list window is closed.";
 #ifdef GERMAN
 static char *string5 = "KARTENFENSTER\n\
 \n\
-Der Menuebalken des Kartenfensters enthaelt die folgenden\n\
+Das Kartenfenster dient zum Erstellen von neuen Eintraegen\n\
+bzw. zum Editieren vorhandener Eintraege.\n\
+Das Eingabefeld enthaelt keinen Rand bzw. (in der Farbversion)\n\
+einen roten Rand. Es kann durch die <tab>- und <esc>-Tasten\n\
+und durch das Druecken der rechten Maustaste in einem Feld\n\
+geaendert werden.\n\
+In der Ressourcedatei bzw. in der Datei .bibviewrc kann dieses\n\
+Verhalten geaendert werden. Dann ist das Eingabefeld das Feld,\n\
+in dem sich der Mauscursor befindet.\n\
+Der dazu erforderliche Eintrag in der Ressourcedatei ist:\n\
+    BibView.focus:false\n\
+Der dazu erforderliche Eintrag im [Options]-Teil von .bibviewrc ist:\n\
+    Focus:false\n\
+\n\
+Die erforderlichen Klammern fuer Feldinhalte werden automatisch\n\
+ergaenzt. Zur Eingabe von Makros und der Zeichen '#' und '@' ist\n\
+erforderlich, ein '@' voranzustellen.\n\
+In der Ressourcedatei bzw. in der Datei .bibviewrc kann dieses\n\
+Verhalten geaendert werden.\n\
+Der dazu erforderliche Eintrag in der Ressourcedatei ist:\n\
+    BibView.orig:true\n\
+Der dazu erforderliche Eintrag im [Options]-Teil von .bibviewrc ist:\n\
+    Orig:true\n\
+De  Menuebalken des Kartenfensters enthaelt die folgenden\n\
 Kommandos:\n\
 \n\
 Verdoppeln:    Ein neues Kartenfenster wird geoeffnet,\n\
@@ -610,36 +628,77 @@ Speichern:     Der Eintrag wird in der BiB gespeichert.\n\
 \n\
 Kopieren:      Der Eintrag wird in eine andere BiB kopiert.\n\
 \n\
+Crossref:      Falls das crossref-Feld des Eintrags nicht leer ist,\n\
+	       wird ein Kartenfenster fuer den crossref-Eintrag\n\
+	       geoeffnet.\n\
+\n\
+Next:          Der Eintrag wird in der BiB gespeichert, und ein\n\
+	       neuer Eintrag kann erfolgen.\n\
+\n\
 Schliessen:    Schliessen des Kartenfensters.";
 #else
 static char *string5 = "CARD WINDOW\n\
 \n\
+The card window is used to create new entries or to edit\n\
+existing entries.\n\
+The field with the input focus has no border or (in the colour\n\
+version) a red border. It can be moved using the <tab> and <esc>\n\
+keys or by clicking the right button of the mouse in a field.\n\
+\n\
+You can change this behaviour in the resource file or in the\n\
+file .bibviewrc. In this case the input focus is set to the\n\
+field where the cursor is placed.\n\
+The necessary entry in the resource file is:\n\
+    BibView.focus:false\n\
+The corresponding entry in the [Options] part of .bibviewrc is:\n\
+    Focus:false\n\
+\n\
+The contents of the fields are entered without the surrounding\n\
+brackets. If you want to enter a macro, '@' or '#', you have to\n\
+use a preceding '@'.\n\
+\n\
+You can change this behaviour in the resource file or in the\n\
+file .bibviewrc.\n\
+The necessary entry in the resource file is:\n\
+    BibView.orig:true\n\
+The corresponding entry in the [Options] part of .bibviewrc is:\n\
+    Orig:true\n\
+\n\
 The menu bar of the card window offers the following commands:\n\
 \n\
-Duplicate: \n\
-\tA new card window is opened in which the field contents\n\
-\t(except mainkey) are taken from the actual card window.\n\
-\tThe actual card window must have been saved, otherwise the\n\
-\tnew card window is empty.\n\
+Duplicate: \
+\tA new card window is opened in which the field \n\
+\t\tcontents (except mainkey) are taken from the\n\
+\t\tactual card window. The actual card window must\n\
+\t\thave been saved, otherwise the new card window is\n\
+\t\tempty.\n\
 \n\
-User Data: \n\
+User Data: \
 \tThe card window is extended with the\n\
-\tfields defined by the user.\n\
+\t\tfields defined by the user.\n\
 \n\
-Annote: \n\
+Annote: \
 \tA window is displayed in which the annote field\n\
-\tof an entry can be edited.\n\
+\t\tof an entry can be edited.\n\
 \n\
-Delete:\t\
+Delete:\t\t\
 The entry is deleted from the BiB.\n\
 \n\
-Save: \t\
+Save: \t\t\
 The entry is saved in the BiB.\n\
 \n\
-Copy: \t\
+Copy: \t\t\
 The entry is copied in another BiB.\n\
 \n\
-Close: \t\
+Crossref: \
+\tIf the entry contains a crossref, the card with the\n\
+\t\tcrossref is opened.\n\
+\n\
+Next: \t\t\
+The entry is saved in the BiB and a new entry can be\n\
+\t\tmade.\n\
+\n\
+Close: \t\t\
 Close the card window.";
 #endif
 
