@@ -197,6 +197,11 @@ int i, lst_width;
    XtAddCallback(lw->copy, XtNcallback, gulCopyListWinCmd, (XtPointer)bp);
    glbCreateFieldMenu("sortMenu", lw->sort, &lw->sortMenu, 
 	      gulSortListWinCmd, (XtPointer) bp);
+   XtInstallAccelerators(lw->list, lw->quit);
+   XtInstallAccelerators(lw->list, lw->print);
+   XtInstallAccelerators(lw->list, lw->save);
+   XtInstallAccelerators(lw->list, lw->copy);
+   XtInstallAccelerators(lw->list, lw->sort);
 
    XtPopup(lw->lstShell, XtGrabNone);
    return(OK);
