@@ -45,6 +45,8 @@
 #define STR_IGNORE_CASE         "IgnoreCase"
 #define STR_PRINT_AS_BIB        "PrintAsBib"
 #define STR_DISPLAY_ERRWIN      "DisplayErrWin"
+#define STR_FOCUS               "Focus"
+#define STR_ORIG                "Orig"
 
 #define STR_FLDINDENT           "fldindent"
 #define STR_CONTINDENT          "contindent"
@@ -114,6 +116,7 @@ char *actual_path;
 extern char *style_file;
 extern int sortedby;
 extern listEntry *list_layout;
+extern OptionsRec options;
 
 extern char requiredfields[MAX_BIBTEX_TYPES+1][MAX_FIELDS];
 extern char standardfields[MAX_BIBTEX_TYPES+1][MAX_FIELDS];
@@ -179,7 +182,7 @@ char processLine;
       latexFooterLen = 0;
    }
    
-   if (glbContIllegalChar(cfgFname) != 1) {
+   if (glbContIllegalChar(cfgFname) != 0) {
       return(ERR_NO_CFGFILE);
    }
 
@@ -363,33 +366,43 @@ int width, fieldnr;
    if (strcmp(token, STR_BEEP_ON_ERROR_OPT) == 0) {
       optionsStatus[OPT_BEEP_ON_ERROR] = 
 			       (strcmp(strupr(value), STR_TRUE) == 0);
+      options.quiet = !optionsStatus[OPT_BEEP_ON_ERROR];
+
    }
    else if (strcmp(token, STR_ICON_ON_DESK_OPT) == 0) {
-      optionsStatus[OPT_ICON_ON_DESKTOP] = 
+      optionsStatus[OPT_ICON_ON_DESKTOP] = options.iconsOnDesk =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_MAKE_BACKUPS_OPT) == 0) {
-      optionsStatus[OPT_BACKUP_ON_SAVE] = 
+      optionsStatus[OPT_BACKUP_ON_SAVE] = options.makeBackup =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_AUTO_CHECK_BIB_OPT) == 0) {
-      optionsStatus[OPT_AUTO_CHECK_BIB] = 
+      optionsStatus[OPT_AUTO_CHECK_BIB] = options.autoCheck =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_REQUIRED_FIELDS_OPT) == 0) {
-      optionsStatus[OPT_REQUIRED_FIELDS] = 
+      optionsStatus[OPT_REQUIRED_FIELDS] = options.reqFields =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_IGNORE_CASE) == 0) {
-      optionsStatus[OPT_IGNORE_CASE] = 
+      optionsStatus[OPT_IGNORE_CASE] = options.ignoreCase =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_PRINT_AS_BIB) == 0) {
-      optionsStatus[OPT_PRINT_AS_BIB] = 
+      optionsStatus[OPT_PRINT_AS_BIB] = options.printAsBib =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else if (strcmp(token, STR_DISPLAY_ERRWIN) == 0) {
-      optionsStatus[OPT_DISPLAY_ERRWIN] = 
+      optionsStatus[OPT_DISPLAY_ERRWIN] = options.displayErrWin =
+			       (strcmp(strupr(value), STR_TRUE) == 0);
+   }
+   else if (strcmp(token, STR_FOCUS) == 0) {
+      optionsStatus[OPT_FOCUS] =  options.focus =
+			       (strcmp(strupr(value), STR_TRUE) == 0);
+   }
+   else if (strcmp(token, STR_ORIG) == 0) {
+      optionsStatus[OPT_ORIG] =  options.orig =
 			       (strcmp(strupr(value), STR_TRUE) == 0);
    }
    else {
@@ -760,6 +773,7 @@ int found, i, type, fieldnr;
 	    }
 	 fieldNames[max_fields] = XtCalloc(strlen(data)+1, sizeof(char));
 	 strcpy(fieldNames[max_fields], data);
+	 is_search_field[max_fields] = '1';
 	 if (akttype == -1){
 	    for (i=0; i<max_bibtex_types; i++)
 	       standardfields[i][max_fields] = '1';
